/**
 * ===========================================================
 * LibRepository : a free Java content repository access layer
 * ===========================================================
 *
 * Project Info:  http://reporting.pentaho.org/librepository/
 *
 * (C) Copyright 2006-2008, by Pentaho Corporation and Contributors.
 *
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation;
 * either version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * [Java is a trademark or registered trademark of Sun Microsystems, Inc.
 * in the United States and other countries.]
 *
 * ------------
 * DummyRepository.java
 * ------------
 */

package org.pentaho.reporting.libraries.repository.dummy;

import java.io.Serializable;

import org.pentaho.reporting.libraries.repository.ContentLocation;
import org.pentaho.reporting.libraries.repository.DefaultMimeRegistry;
import org.pentaho.reporting.libraries.repository.MimeRegistry;
import org.pentaho.reporting.libraries.repository.Repository;

/**
 * A dummy repositor is a empty repository that swallows all content fed into it.
 *
 * @author Thomas Morgner
 */
public class DummyRepository implements Repository, Serializable
{
  private DummyContentLocation location;
  private MimeRegistry mimeRegistry;

  /**
   * Creates a new dummy repository.
   */
  public DummyRepository()
  {
    location = new DummyContentLocation(this, "");
    mimeRegistry = new DefaultMimeRegistry();
  }

  /**
   * Returns the repositories root directory entry.
   *
   * @return the root directory.
   */
  public ContentLocation getRoot()
  {
    return location;
  }

  /**
   * Returns the repositories MimeRegistry, which is used return basic content-type information about the items stored
   * in this repository.
   *
   * @return the mime registry.
   * @see MimeRegistry
   */
  public MimeRegistry getMimeRegistry()
  {
    return mimeRegistry;
  }
}
